==> elephant-archives-domain-0.0.448-sources.jar: com/xforceplus/ultraman/app/elephantarchives/entity/ArchiveObjectExpand.java <==
package com.xforceplus.ultraman.app.elephantarchives.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-08-10
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ArchiveObjectExpand implements Serializable {

  private static final long serialVersionUID=1L;

  private Long entityId;

  private String dataObjectType;

  private String originalCustodyType;

  private String manualFlagCustodyType;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime backlogDate;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("entity_id", entityId);
      map.put("data_object_type", dataObjectType);
      map.put("original_custody_type", originalCustodyType);
      map.put("manual_flag_custody_type", manualFlagCustodyType);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("backlog_date", BocpGenUtils.toTimestamp(backlogDate));
      return map;
  }

  public static ArchiveObjectExpand fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ArchiveObjectExpand entity = new ArchiveObjectExpand();
    if(map.containsKey("entity_id")) {
      Object obj = map.get("entity_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setEntityId((Long)obj);
        } else if(obj instanceof String) {
          entity.setEntityId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setEntityId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("data_object_type")) {
      Object obj = map.get("data_object_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDataObjectType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("original_custody_type")) {
      Object obj = map.get("original_custody_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOriginalCustodyType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("manual_flag_custody_type")) {
      Object obj = map.get("manual_flag_custody_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setManualFlagCustodyType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("backlog_date")) {
      Object obj = map.get("backlog_date");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setBacklogDate(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setBacklogDate((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setBacklogDate(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setBacklogDate(null);
      }
    }
    return entity;
  }
}

==> elephant-archives-domain-0.0.547-sources.jar: com/xforceplus/ultraman/app/elephantarchives/entity/ArchiveObjectExpand.java <==
package com.xforceplus.ultraman.app.elephantarchives.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-09-09
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ArchiveObjectExpand implements Serializable {

  private static final long serialVersionUID=1L;

  private Long entityId;

  private String dataObjectType;

  private String originalCustodyType;

  private String manualFlagCustodyType;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime backlogDate;

  private Long associateVoucherId;

  private String associateVoucherNo;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("entity_id", entityId);
      map.put("data_object_type", dataObjectType);
      map.put("original_custody_type", originalCustodyType);
      map.put("manual_flag_custody_type", manualFlagCustodyType);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("backlog_date", BocpGenUtils.toTimestamp(backlogDate));
      map.put("associate_voucher_id", associateVoucherId);
      map.put("associate_voucher_no", associateVoucherNo);
      return map;
  }

  public static ArchiveObjectExpand fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ArchiveObjectExpand entity = new ArchiveObjectExpand();
    if(map.containsKey("entity_id")) {
      Object obj = map.get("entity_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setEntityId((Long)obj);
        } else if(obj instanceof String) {
          entity.setEntityId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setEntityId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("data_object_type")) {
      Object obj = map.get("data_object_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDataObjectType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("original_custody_type")) {
      Object obj = map.get("original_custody_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOriginalCustodyType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("manual_flag_custody_type")) {
      Object obj = map.get("manual_flag_custody_type");
      if(obj != null) {
        if(obj instanceof String){
          entity.setManualFlagCustodyType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("backlog_date")) {
      Object obj = map.get("backlog_date");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setBacklogDate(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setBacklogDate((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setBacklogDate(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setBacklogDate(null);
      }
    }
    if(map.containsKey("associate_voucher_id")) {
      Object obj = map.get("associate_voucher_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setAssociateVoucherId((Long)obj);
        } else if(obj instanceof String) {
          entity.setAssociateVoucherId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setAssociateVoucherId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("associate_voucher_no")) {
      Object obj = map.get("associate_voucher_no");
      if(obj != null) {
        if(obj instanceof String){
          entity.setAssociateVoucherNo((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}
